from rest_framework import serializers

from arkindex.process.models import GitRef, GitRefType, Revision
from arkindex.project.serializer_fields import EnumField


class GitRefSerializer(serializers.ModelSerializer):
    """
    Serialize a git reference for a repository
    """
    type = EnumField(GitRefType)

    class Meta:
        model = GitRef
        fields = (
            "id",
            "name",
            "type",
        )


class RevisionSerializer(serializers.ModelSerializer):
    """
    Serialize a repository revision
    """

    date = serializers.DateTimeField(source="created")
    commit_url = serializers.URLField(read_only=True)

    class Meta:
        model = Revision
        fields = (
            "id",
            "date",
            "hash",
            "message",
            "author",
            "commit_url",
            "repo_id",
        )


class RevisionWithRefsSerializer(serializers.ModelSerializer):
    """
    Serialize a repository revision with its associated references
    """
    refs = GitRefSerializer(many=True, read_only=True)
    commit_url = serializers.URLField(read_only=True)

    class Meta:
        model = Revision
        fields = (
            "id",
            "hash",
            "author",
            "message",
            "created",
            "commit_url",
            "refs",
        )
