from django.contrib import admin


class ArchivedListFilter(admin.SimpleListFilter):
    """
    Allows filtering on `archived__isnull`, because the Django admin
    does not support filtering by anything other than a model field.
    """
    title = "archival state"
    parameter_name = "archived"

    def lookups(self, request, model_admin):
        return [
            ("true", "Archived"),
            ("false", "Not archived"),
        ]

    def queryset(self, request, queryset):
        if self.value() == "true":
            return queryset.filter(archived__isnull=False)
        if self.value() == "false":
            return queryset.filter(archived__isnull=True)
        return None
